package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````?",```````!``````````/BA````
M````!0```$``.``*`$``&P`:``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````A`````````"$``````````0`````````#``!P
M!````*:@`````````````````````````````%,````````````````````!
M``````````$````%````````````````````````````````````L)@`````
M``"PF``````````0`````````0````8```!PFP```````'"K````````<*L`
M``````#@!`````````@%`````````!`````````"````!@```(B;````````
MB*L```````"(JP```````#`"````````,`(````````(``````````0````$
M````E`(```````"4`@```````)0"````````1`````````!$``````````0`
M````````4.5T9`0```!0D0```````%"1````````4)$```````#L````````
M`.P`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````<)L```````!P
MJP```````'"K````````D`0```````"0!`````````$`````````+VQI8B]L
M9"UL:6YU>"UR:7-C=C8T+6QP-C1D+G-O+C$`````!````!0````#````1TY5
M`&,0)JFER/'Z-U5L1\5TH9"+E"WP!````!`````!````1TY5```````$````
M#P````````!A````9@``````````````4@````4```````````````8`````
M```````````````\`````````!`````C````7P`````````P````2@```$L`
M```]````6@```&,````O````+```````````````%P```$,````Q````````
M``````!,````50```#L`````````5@```&4````J````*`````<`````````
M#P`````````Z````6P```$D```!%`````````#<```!=````-@```"X````:
M``````````````!3````1@```#D```!"````%````````````````````#\`
M```F````````````````````+0```!(`````````%@```&0````<````````
M````````````&0```#@````^````30`````````T`````````$``````````
M`````%P`````````3@````````!!````7@```$<```!$````)P````T`````
M`````````````````````````````````````````````````````P``````
M````````````````````````````````````````````````````````"P``
M``````!A````3P``````````````#@```!L````$`````````!\`````````
M40``````````````"``````````@``````````````!@`````````"L`````
M`````````%D`````````$0````````!B````*0```%<``````````````$@`
M```R`````````"(`````````)````"$````=````#``````````*````5```
M```````>`````````````````````````````````````````!4`````````
M```````````8```````````````S````)0``````````````"0``````````
M````````````````````4````#4`````````$P````(`````````6```````
M````````$0```$@````$````"````""0$`$%0`3$*`(!!("&!(2"B0`""2`$
M"(B`$$&Z``*(`````$@```!+````3@```$\```!7````6````%H```!<````
M70```%X```!@````8@```&,```!E``````````````!NQ=\?SMY'+6M_FGPN
MQ9NVU&34?"'_Y`[9<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RRZXY)\^J%L8)E/
MPYMK"4/69J_,9AE^"H="1=7LB0=PTW-0G]@S8MOM/L_2;!6,)<P,.I<+_V'R
M87^IG)O@IP(*:QJ>4*/@^TD`````````````````````````````````````
M``````,`#0#P(0``````````````````[@(``!$`````````````````````
M````K`(``!(`````````````````````````?0$``!(`````````````````
M````````A0```!(`````````````````````````$P(``!(`````````````
M````````````DP(``!(`````````````````````````R0$``!(`````````
M````````````````K@```!(`````````````````````````C`(``!(`````
M````````````````````I````!(`````````````````````````3P(``!(`
M````````````````````````W0$``!(`````````````````````````?0``
M`!$`````````````````````````E0```!(`````````````````````````
ML`$``!(`````````````````````````W@(``!(`````````````````````
M`````P(``!(`````````````````````````(0$``!(`````````````````
M````````H0$``!(`````````````````````````TP```!(`````````````
M````````````T`$``!(`````````````````````````PP```!(`````````
M````````````````6````!(``````````````````````````0```"``````
M````````````````````&`$``!(`````````````````````````Q`(``!(`
M````````````````````````'0```"``````````````````````````C@``
M`!(`````````````````````````R@```!(`````````````````````````
MM@(``!(`````````````````````````DP$``!(`````````````````````
M````>P```!$`````````````````````````V0```!8`````````````````
M````````6P$``!(`````````````````````````[````!(`````````````
M````````````A`$``!(`````````````````````````10$``!(`````````
M````````````````8@(``!(`````````````````````````P@$``!(`````
M````````````````````!P$``!(`````````````````````````SP(``!(`
M````````````````````````M0$``!(`````````````````````````-@$`
M`!(`````````````````````````L0(``!(`````````````````````````
M;P$``!(`````````````````````````UP$``!(`````````````````````
M````G@(``!(`````````````````````````=@$``!(`````````````````
M````````+P$``!(`````````````````````````F@$``!$`````````````
M````````````-`(``!(`````````````````````````BP$``!(`````````
M````````````````C0```!(`````````````````````````20```"(`````
M````````````````````'P(``!(`````````````````````````4P$``!(`
M````````````````````````O0$``!(`````````````````````````YP(`
M`!(`````````````````````````@`(``!(`````````````````````````
M[@$``!(`````````````````````````L0,``!(`````````````````````
M````<P(``!$`````````````````````````M0```!(`````````````````
M````````_````!(`````````````````````````0`(``!(`````````````
M````````````-P```!(`````````````````````````G````!(`````````
M````````````````8@$``!(`````````````````````````:@```!(`````
M````````````````````_`$``!(`````````````````````````N@,``!(`
M#0!&3````````*0`````````3`0``!(`#0"010````````8%````````1```
M`!(`#0#P(0```````(H!````````,0,``!(`#0"4/`````````(`````````
M3P,``!(`#0"62@```````+`!````````<@0``!(`#0"6/````````-8!````
M````,@0``!``%P!0L```````````````````0@,``!(`#0!L/@```````"(`
M````````90,``!(`#0#H0@```````$X`````````T@,``!$`#@#83P``````
M``0`````````#P0``!(`#0`^30```````-P`````````*@0``!(`#0"F.P``
M`````"@`````````1P0``!``%P!XL```````````````````8`0``!(`#0"V
M1````````-H`````````B00``!(`#0`V0P```````$0`````````X0,``!``
M%@``L```````````````````B0,``!(`#0"./@````````(!````````_0,`
M`!``\?\`N```````````````````600``!``%@!0L```````````````````
M?P0``!$`%@!(L`````````@`````````&@0``!``%@!0L```````````````
M````YP,``!(`#0!\(P```````"(`````````[@,``!``%@``L```````````
M````````/@0``!(`#0#J3````````%0`````````XP,``"``%@``L```````
M````````````Q@,``!``%P!XL```````````````````GP,``!(`#0">1```
M`````!@`````````<P,``!(`#0#..P```````,8`````````E0,``!(`#0`:
M3@```````+(!````````D00``!(`#0"0/P```````%@#`````````%])5$U?
M9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E9VES=&5R5$U#;&]N951A
M8FQE`%]?;&EB8U]S=&%R=%]M86EN`%]?8WAA7V9I;F%L:7IE`%]?<F5G:7-T
M97)?871F;W)K`%]?<W1A8VM?8VAK7V9A:6P`7U]E;G9I<F]N`'-T<FYC;7``
M;'-T870V-`!A8V-E<W,`;W!E;F1I<@!R96%D9&ER-C0`<W1R;&5N`%]?<W!R
M:6YT9E]C:&L`=6YL:6YK`&-L;W-E9&ER`')M9&ER`%!,7V-U<G)E;G1?8V]N
M=&5X=`!B;V]T7T1Y;F%,;V%D97(`4&5R;%]N97=84P!097)L7VYE=UA37V9L
M86=S`')E861L:6YK`%!E<FQ?<W9?<V5T<'8`;65M8VAR`%!E<FQ?<W9?<V5T
M<'9N`%]?;65M;6]V95]C:&L`<F5A;&QO8P!G971P:60`7U]M96UC<'E?8VAK
M`'-T<F-H<@!S=')D=7``<W1R=&]K`'-T<F-M<`!S=')R8VAR`&UE;6-P>0!S
M=&1E<G(`7U]V9G!R:6YT9E]C:&L`97AI=`!L<V5E:S8T`')E860`;65M8VUP
M`&=E='5I9`!S=')S='(`;6MD:7(`7U]E<G)N;U]L;V-A=&EO;@!?7V9P<FEN
M=&9?8VAK`&]P96XV-`!097)L7V=V7V9E=&-H<'8`4&5R;%]G971?<W8`4&5R
M;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]M9U]S970`4&5R;%]S>7-?:6YI=#,`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?871F;W)K7VQO8VL`4$Q?9&]?=6YD
M=6UP`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7W!A<G-E`'!E<FQ?9&5S=')U
M8W0`<&5R;%]F<F5E`%!E<FQ?<WES7W1E<FT`<&5R;%]A;&QO8P!P97)L7V-O
M;G-T<G5C=`!P97)L7W)U;@!M96US970`7U]S=&%C:U]C:&M?9W5A<F0`;&EB
M<&5R;"YS;P!L:6)C+G-O+C8`;&0M;&EN=7@M<FES8W8V-"UL<#8T9"YS;RXQ
M`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%A37TEN=&5R;F%L<U]0
M05)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT7V5X96-?<')O8P!P
M87)?9&ER;F%M90!S:&%?9FEN86P`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U
M:60`<&%R7V-L96%N=7``7U]"4U-?14Y$7U\`7TE/7W-T9&EN7W5S960`7U]D
M871A7W-T87)T`%]?1$%405]"14=)3E]?`%]?9VQO8F%L7W!O:6YT97(D`'-H
M85]U<&1A=&4`7U]31$%405]"14=)3E]?`'AS7VEN:70`7U]B<W-?<W1A<G0`
M<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U<%]L
M:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P87)?:6YI
M=%]E;G8`1TQ)0D-?,BXS-`!'3$E"0U\R+C,S`$=,24)#7S(N,C<`+W5S<B]L
M:6(O<&5R;#4O-2XS."XR+W)I<V-V-C0M;&EN=7@M=&AR96%D+6UU;'1I+T-/
M4D4````````"``$``P`#``$``0`#``,``P`#``$``P`#``,``P`!``$``0`#
M``,``P`#``,``0`#``$``0`$``,``0`#``,``0`#``$``P`#``$``P`!``$`
M`P`!``,``P`#``$``P`#``,``0`#``0``P`!``,``P`#``$``P`#``$``P`!
M``$`!0`#``,``P`#``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``````````$``P`+`P``$```
M`$````"TD98&```%`)X$```0````LY&6!@``!`"I!```$````(>1E@8```,`
MM`0````````!``$`%0,``!``````````AY&6!@```@"T!````````'"K````
M`````P````````">(P```````'BK`````````P`````````R)````````("K
M`````````P````````#X(P```````/BO`````````P````````#P(0``````
M``"P`````````P``````````L````````!BP`````````P`````````X40``
M`````""P`````````P`````````0D0```````"BP`````````P`````````8
MD0```````#"P`````````P`````````@D0```````#BP`````````P``````
M```HD0```````$BP`````````P````````"@4P```````*"O`````````@``
M``(``````````````*BO`````````@````P``````````````+"O````````
M`@````X``````````````+BO`````````@```!D``````````````,"O````
M`````@```!P``````````````,BO````````"P```"(``````````````-"O
M`````````@```"0``````````````-BO`````````@```"<`````````````
M`."O`````````@```#,``````````````.BO`````````@```#<`````````
M`````/"O`````````@```#\``````````````,BM````````!0````,`````
M`````````-"M````````!0````0``````````````-BM````````!0````4`
M`````````````."M````````!0````8``````````````.BM````````!0``
M``<``````````````/"M````````!0````@``````````````/BM````````
M!0````D```````````````"N````````!0````H```````````````BN````
M````!0````L``````````````!"N````````!0````T``````````````!BN
M````````!0````\``````````````""N````````!0```!``````````````
M`"BN````````!0```!$``````````````#"N````````!0```!(`````````
M`````#BN````````!0```!,``````````````$"N````````!0```!0`````
M`````````$BN````````!0```!4``````````````%"N````````!0```!8`
M`````````````%BN````````!0```!<``````````````&"N````````!0``
M`!@``````````````&BN````````!0```!H``````````````'"N````````
M!0```!L``````````````'BN````````!0```!T``````````````("N````
M````!0```!X``````````````(BN````````!0```!\``````````````)"N
M````````!0```"```````````````)BN````````!0```",`````````````
M`*"N````````!0```"4``````````````*BN````````!0```"8`````````
M`````+"N````````!0```"@``````````````+BN````````!0```"D`````
M`````````,"N````````!0```"H``````````````,BN````````!0```"L`
M`````````````-"N````````!0```"P``````````````-BN````````!0``
M`"T``````````````."N````````!0```"X``````````````.BN````````
M!0```"\``````````````/"N````````!0```#```````````````/BN````
M````!0```#$```````````````"O````````!0```#(```````````````BO
M````````!0```#0``````````````!"O````````!0```#4`````````````
M`!BO````````!0```#8``````````````""O````````!0```#@`````````
M`````"BO````````!0```#D``````````````#"O````````!0```#H`````
M`````````#BO````````!0```#L``````````````$"O````````!0```#P`
M`````````````$BO````````!0```#T``````````````%"O````````!0``
M`#X``````````````%BO````````!0```$```````````````&"O````````
M!0```$$``````````````&BO````````!0```$(``````````````'"O````
M````!0```$,``````````````'BO````````!0```$0``````````````("O
M````````!0```$4``````````````(BO````````!0```$8`````````````
M`)"O````````!0```$<`````````````````````````EY,``#,#PT$#OH/X
M$P-#_9."@_@34Q,`@[*"`&<`#@`7G@```SZ.]V<##@`3````%YX```,^#O=G
M`PX`$P```!>>```#/H[V9P,.`!,````7G@```SX.]F<##@`3````%YX```,^
MCO5G`PX`$P```!>>```#/@[U9P,.`!,````7G@```SZ.]&<##@`3````%YX`
M``,^#O1G`PX`$P```!>>```#/H[S9P,.`!,````7G@```SX.\V<##@`3````
M%YX```,^CO)G`PX`$P```!>>```#/@[R9P,.`!,````7G@```SZ.\6<##@`3
M````%YX```,^#O%G`PX`$P```!>>```#/H[P9P,.`!,````7G@```SX.\&<#
M#@`3````%YX```,^CN]G`PX`$P```!>>```#/@[O9P,.`!,````7G@```SZ.
M[F<##@`3````%YX```,^#NYG`PX`$P```!>>```#/H[M9P,.`!,````7G@``
M`SX.[6<##@`3````%YX```,^CNQG`PX`$P```!>>```#/@[L9P,.`!,````7
MG@```SZ.ZV<##@`3````%YX```,^#NMG`PX`$P```!>>```#/H[J9P,.`!,`
M```7G@```SX.ZF<##@`3````%YX```,^CNEG`PX`$P```!>>```#/@[I9P,.
M`!,````7G@```SZ.Z&<##@`3````%YX```,^#NAG`PX`$P```!>>```#/H[G
M9P,.`!,````7G@```SX.YV<##@`3````%YX```,^CN9G`PX`$P```!>>```#
M/@[F9P,.`!,````7G@```SZ.Y6<##@`3````%YX```,^#N5G`PX`$P```!>>
M```#/H[D9P,.`!,````7G@```SX.Y&<##@`3````%YX```,^CN-G`PX`$P``
M`!>>```#/@[C9P,.`!,````7G@```SZ.XF<##@`3````%YX```,^#N)G`PX`
M$P```!>>```#/H[A9P,.`!,````7G@```SX.X6<##@`3````%YX```,^CN!G
M`PX`$P```!>>```#/@[@9P,.`!,````7G@```SZ.WV<##@`3````%YX```,^
M#M]G`PX`$P```!>>```#/H[>9P,.`!,````7G@```SX.WF<##@`3````%YX`
M``,^CMUG`PX`$P```!>>```#/@[=9P,.`!,````7G@```SZ.W&<##@`3````
M%YX```,^#MQG`PX`$P```!>>```#/H[;9P,.`!,````7G@```SX.VV<##@`3
M````'7&&[*;DJH>BZ,K@3OR7E```@[0DVB[H,N0,"#``:`@^SIQ@/O2!1^_P
MG_<7E@```S;&V+*%%Y4```,U)=OO(/!9EY<``(.WY]N#QP<`\<^7EP``@[>'
MV!>4```3!`3ADI>88W))@T>G2QL%20`.!9/G-P`C#?=*[_"?[<)E\D<(Y)AA
M#2FJAACA%S<``!,'9Q$8Y1>7```#-T?<&.D7-P``$P>G$!CM!4=C6?<,&X@W
M`$*&H0411XAADQ<W`+:7!2>(XZ$%XQD'_YL'!@".!PALMI<!1TJ&EQ4``).%
M15XCL`<`[_#?NSW%"&R3"4$"[_`?W"J)SH47-0``$P4%WN\0X#HIS0AL[_"?
MM>_P7\TB=YQ@N8\!1[WGYF!&9*9DXGE*A09I)6&"@._P?\@7E```$P2DTPCL
M(<7O\'_1EY<``(.WI\F%9C.'1P`88S:7(P<'FC&W"&SO\)^\>;<(:`'%[R!0
M#T6WSH47-0``$P5ES^\0P#,(Z%G5Y;>11X&_!47O\/^X[_"_Y0``[P`@`JJ'
M%Y4```,U9<>"93``$W$!_X%&`4<*B._PG^`"D)>1``"3@2%&@H```!>5```3
M!67*EY<``).'Y\ECB*<`EY<``(.WI[^1PX*'@H`7E0``$P5%R)>5``"3A<7'
MB8V3US5`_9&^E86%F<67EP``@[=GO9'#@H>"@$$1(N`7E```$P1$Q8-'!``&
MY(7CEY<``(.WQ[V1QQ>5```#-:6^@I?O\+_XA4<C`/0`HF`"9$$!@H!IOQ,!
M`=0C.($J(SP1*B,TD2HC,"$K(SPQ*2,X02D7E````S0$M30`P6Y]7QQ@(S3Q
M*(%'DPB%`Y,"A0<VB!-?#P*W#_\`DXX.\`.V"`!!"*$(DU4&`A,7A@&3$X8`
MDU>&`A->A@"35(8#$Y.%`3-WYP&S\_,!L_?7`3-G=P`S?MX!Q8\S<^,!H@4S
M9\<!&U:&`;/G9P"S]?4!48_-CR,XZ/XC//C^XY(2^_U5QG]F?PIGXFX"?B)S
MPGAB>(9CDX0&((&1$:"R@[!BG&*Z@J$&L8^SQ_<!L\?7`1.7%P#]@UV/;8^X
M_OJ/\HX6CQJ.1H/"B!Z(XYF6_(,^!0"B;P,X!0$#,X4`@SB%`0,^!0(WAX):
M$P>7F9/7O@$3EEX`78ZZGQ-?(P"3%^,!;8[RG[-&&`&SY^<!L_9F`'Z6PF\S
M_[<`L\86`3:6LT;H`6V.L_;6`;J?DQ)6`)-4M@'&G[/&!@'^EK/OD@`3V2X`
MDY/N`?Z6XF^SXR,!L\=W`/&/NI_MCK/'YP'"GY.45@`3V;8!DQ+F`?Z7"8*"
M?[/BP@`SYB0!LI<SQE,`NI^S\[,`=8[MCWZ?,T9V`).45P`3V;<!DY_F`7J6
MB8(B?[/OWP"SYB0!-I:SQO(!;8ZS\K(`_8XZGQZ?DQ16`!-9M@&SQE8`DY/G
M`8F#L^/S`/J6L^<D`;Z6,_^V`,)VL\=_`/&/L_^_`+J6EI:3%%\`$UF_`;/'
M]P&VE[/F)`&VEY,2Y@$)@K/BP@`S]K<`XG>SQE,`L_;F`;/SLP"ZE_Z7DQ16
M`!-9M@&SQG8`OI:SYR0!OI:3'^\!$U\O`+/O[P$S_[8`AF:SQ_(!\8^S\K(`
MNI:>EI,47P`36;\!L\=7`+:7L^8D`;:7DQ/F`0F"L^/#`#/VMP"F9[/&?P"S
M]N8!L_^_`+J7EI>3%%8`$UFV`;/&]@&^EK/G)`&^EI,2[P$37R\`L^+B`3/_
MM@#&9K/'4P#QC[/SLP"ZEOZ6DQ1?`!-9OP&SQW<`MI>SYB0!MI>3'^8!"8*S
M[\\`,_:W`.9GL\;R`;/VY@&S\K(`NI>>EY,45@`36;8!L\96`+Z6L^<D`;Z6
MDQ/O`1-?+P"SX^,!,_^V`(9VL\=_`/&/L_^_`+J6EI:3%%\`$UF_`;/']P&V
ME[/F)`&VEY,2Y@$)@K/BP@`S]K<`IG>SQE,`L_;F`;/SLP"ZE_Z7DQ16`!-9
MM@&SQG8`OI:SYR0!OI:3'^\!$U\O`+/O[P$S_[8`QG:SQ_(!\8^S\K(`NI:>
MEI,47P`36;\!L\=7`+:7L^8D`;:7DQ/F`0F"L^/#`#/VMP#F=[/&?P"S]N8!
ML_^_`+J7EI>3%%8`$UFV`;/&]@&^EK/G)`&^EI,2[P$37R\`L^+B`3/_M@"*
M9K/'4P#QC[/SLP"ZEOZ6DQ1?`!-9OP&SQW<`MI>SYB0!MI>3'^8!"8*S[\\`
M,_:W`*IGL\;R`;/VY@&S\K(`NI>>EY-4M@&3$U8`L\96`!,9[P&^EA-?+P"S
MYY,`RF,S;^D!OI:SQ^\![8ZS_[\`NI/QCYZ2D]2V`;/']P&3DU8`L^.3`):7
MZF23$N8!"8*SXL(`GI?MCS-&7P"ZE#-_OP`3V;<!=8Z3DU<`II\S1N8!L^,C
M`;/SLP!^EI.?Y@&)@AZ6L^_?``IYLW2V`+/&\@']CK/RL@"3DU0`D]FT`3J9
M,\=6`+/F,P&3D^<!B8.SX_,`2I^SQW\`[8YZE[&/*G8S#]<`-_?9;A,'%[JS
M>;\`$]FY`3J6DY99`!:6[8^SYB8!LI?MCKZ6DY+D`<IWB8"SXI(`,_FV`#/&
M4P"S_[\`DU2Y`;J7,T_F`1,660`S?[\`_I=%COJ7;8X^EI.?Z0'J=Y/9*0"S
M[S\!LW2V`#//\@&S\[,`D]FT`;J7,T_?`).65``S?[\`GI>SYC8!^I?MCKZ6
M$Q_I`8YG$UDI`#-O+P&S\[8`,\GO`;/YL@"ZE[-"R0`3V;,!$Y93`+/RL@#.
MES-F)@&6EVV./I:3DN0!KF>)@+/BD@`S25\`LW2V`+/YOP"ZE[-/V0`3V;0!
MDY94`+/_OP#.E[/F)@'^E^V.OI:3G^,!SF>3TR,`L^]_`#/)\@&S\[8`LWF_
M`+J7,T_)`!/9LP$3EE,`,W^_`,Z7,V8F`?J7;8X^EA.?Y`'N9XF`,V^?`#/)
M[P&S=+8`L_FR`+J7LT+9`!/9M`&3EE0`L_*R`,Z7L^8F`9:7[8Z^EI.2XP&.
M=Y/3(P"SXG(`,TE?`+/SM@"S^;\`NI>S3\D`$]FS`1.64P"S_[\`SI<S9B8!
M_I=MCCZ6DY_D`:YWB8"S[Y\`,\GR`;-TM@"S>;\`NI<S3]D`$]FT`9.65``S
M?[\`SI>SYB8!^I?MCKZ6$Y_C`<YWD],C`#-O?P`SR>\!L_.V`+/YL@"ZE[-"
MR0`3V;,!$Y93`+/RL@#.ES-F)@&6EVV./I:3DN0![G>)@+/BD@`S25\`LW2V
M`+/YOP"ZE[-/V0`3V;0!DY94`+/_OP#.E[/F)@'^E^V.OI:3G^,!DF>3TR,`
ML^]_`#/)\@&S\[8`LWF_`+J7,T_)`!/9LP$3EE,`,W^_`,Z7,V8F`?J7;8X^
MEA.?Y`&R9XF`,V^?`#/)[P&S=+8`L_FR`+J7LT+9`!/9M`&3EE0`L_*R`,Z7
ML^8F`9:7[8Z^EI.2XP'29Y/3(P"SXG(`,TE?`+/SM@"S^;\`NI>S3\D`$]FS
M`1.64P"S_[\`SI<S9B8!_I=MCCZ6DY_D`?)GB8"S[Y\`,\GR`;-TM@"S>;\`
MNI<S3]D`$]FT`9.65``S?[\`SI>SYB8!^I?MCKZ6$Y_C`9)WD],C`#-O?P`S
MR>\!L_.V`+/YL@"ZE[-"R0`3V;,!$Y93`+/RL@#.ES-F)@&6EVV./I:3DN0!
MLG>)@+/BD@`S25\`LW2V`+/YOP"ZE[-/V0`3V;0!DY94`+/_OP#.E[/F)@'^
ME^V.OI:3G^,!TG>3TR,`L^]_`#/YM@"SP_(!LWF_`+J7,\_#`)-3N0$3%ED`
M,W^_`,Z7,V9V`&V.^I<SC\<`DY/D`?)WB8"SXY,`,\9_`+-TOP"S\K(`NI>Q
MCNV.D]FT`9:7DY)4`+:7L^8R`;:7$Q;I`99F$UDI`#-F)@$SR<,`L_*W`+/_
MOP"S1^D!NI:3V;(!_I83F5(`L_^W`#-I.0'^ELJ6$Y_D`8F`,V^?`#?WQB.S
M=+8`_5?UC;9F@9,*!Q,'Q\VS?_\`,V;F`3/Y]`&ZEC-V5@"S\_,`MI.3V;4!
M,V8F`1.950`>EK-C.0$>EK-S]@"3EN(!5F:3TB(`L^96`+/R]@`S;]\`,_E?
M`#J6,W^_`+*4D]FS`3-O+P$3F5,`)I^S9#D!$Y;E`2:?B8'V9$V.LW7V`-&.
M,W__`#/YL@"S]G8`NI3^E)-9OP&SYB8!$QE?`*:6LV0Y`1.:XP&3WR,`II:6
M=+-O^@&S\_\`,V;V`?V.,_EU`+J4,W;F`::2,V8F`9.45@`3V;8!L^0D`1:6
MDQGO`2:6$U\O`+9T,^_I`;-R_P"S[^\!?8XS^5,`L__?`+J4L^\O`:Z4$QE6
M`)-9M@&3E>8!B8+5C;.&GP"S;SD!_I;6?[/T]0`S;[\`_8XS^9(`NI\S?\\`
M,V\O`?Z3$YE6`)/9M@&3'^8!"8*S[\\`,P9_`#-O.0%ZEG9_L_/_`+/E]0%]
MCC/Y=``ZG_6-L^4E`?J2$QE6`)-9M@$3G^8!B8(S;]\`LX95`+-E.0&NEIIE
MLW+_`+/O[P']CC/Y4P"ZE;/_SP"S[R\!KI03F58`D]FV`9,5Y@$)@M&-,X:?
M`+-O.0%^EKIOL_3U`#-OOP!]CC/YD@"ZGS-_WP`S;R\!_I,3&58`DUFV`9.?
MY@&)@K/OWP"S!G\`,V\Y`?J66F^S\_\`L^7U`?V.,_ET`#J?\8VSY24!^I(3
MF58`D]FV`1,?Y@$)@C-OSP`SAE4`LV4Y`2Z6^F6S<O\`L^_O`7V.,_E3`+J5
ML__?`+/O+P&NE!,95@"36;8!DY7F`8F"U8VSAI\`LV\Y`?Z6FG^S]/4`,V^_
M`/V.,_F2`+J?,W_/`#-O+P'^DQ.95@"3V;8!DQ_F`0F"L^_/`#,&?P`S;SD!
M>I8Z?[/S_P"SY?4!?8XS^70`.I_UC;/E)0'ZDA,95@"36;8!$Y_F`8F",V_?
M`+.&50"S93D!KI;:=;-R_P"S[^\!_8XS^5,`NI6S_\\`L^\O`:Z4$YE6`)/9
MM@&3%>8!"8+1C3.&GP"S9#D!)I;Z=+/_]0`S;[\`?8XS^?(!,W_?`+J4,V\O
M`9Z4$QE6`)-9M@&3D^8!B8*SX],`LP:?`+-D.0$>:3/_\P"SY74`II;QC;/T
M[P$ZF?V.%IG%C9.95@`3VK8!DU(F`),4Y@'*E3YIL^14`#/F20&S\O0`LI4S
MYI,`=8ZS\_4`.IFS=5\`?IF3F5,`$]JS`4V.D]\F`).5Y@%*EK/F20&SY?4!
M-I:SYK0`LW3V`%YFL__U`#/Y\@&S]G8`.I9ZEK/F)@$3GU0`$]FT`3-O+P&R
MEGYI$Y;C`9/3(P`S9G8`LW/V`/J6T8W]CC/Z?P#EC3J9$Y]6`)/9M@$6F;/E
M10&S8C\!RI43WR0`$YGD`;-DZ0$>?[/R\@"6E46.L_+T`#/Y]0`S^E,`=8XZ
MGY-9N0$3%UD`?I\S9D8!LV\W`7J6DYGF`1/?)@`S[^D!L\;D`;/__P"MCC>W
MF#*^=;*?"@<3!V<=L_G_`)/4N0&ZE1.660">E?V.18Z3$^D!$UDI`+/C(P%]
MCJZ6LX7&`#-&?P`S1O8!WG^S]/4`$]FT`;J?DY94`):??8ZSYB8!_8Y^EC:6
MDY_I`?YVD]DI`+/O/P$S>?8`L\+S`;-Y_P"ZEC//L@"34KD!DQ59`#-__P#.
MEK/E50#ZEOV-MI43G^0!@S8!((F`,V^?`+/"[P&S]/4`L_/S`)/9M`&ZEK/"
MP@`3EE0`L_+R`)Z6,V8V`9:6?8XVEI,2Z0&#-H$@$UDI`+/B(@&S<_8`,TE?
M`+/Y_P"ZEK-/N0`3V;,!DY53`+/__P#.EK/E)0'^EOV-MI63G^0!@S8!(8F`
ML^^?`#/)\@&S]/4`LWG_`+J6,T_)`!/9M`$3EE0`,W__`,Z6,V8F`?J6?8XV
MEA.?XP&#-H$AD],C`#-O?P`SR>\!LW/V`+/Y\@"ZEK-"N0`3V;,!DY53`+/R
M\@#.EK/E)0&6EOV-MI63DN0!@S8!(HF`L^*2`#-)7P"S]/4`L_G_`+J6LT_)
M`!/9M`$3EE0`L___`,Z6,V8F`?Z6?8XVEI.?XP&#-H$BD],C`+/O?P`SR?(!
MLW/V`+-Y_P"ZEC-/N0`3V;,!DY53`#-__P#.EK/E)0'ZEOV-MI43G^0!@S8!
M(XF`,V^?`#/)[P&S]/4`L_GR`+J6LT+)`!/9M`$3EE0`L_+R`,Z6,V8F`9:6
M?8XVEI.2XP&#-H$CD],C`+/B<@`S25\`LW/V`+/Y_P"ZEK-/N0`3V;,!DY53
M`+/__P#.EK/E)0'^EOV-MI63G^0!@S8!)(F`L^^?`#/)\@&S]/4`LWG_`+J6
M,T_)`!/9M`$3EE0`,W__`,Z6,V8F`?J6?8XVEA.?XP&#-H$DD],C`#-O?P`S
MR>\!LW/V`+/Y\@"ZEK-"N0`3V;,!DY53`+/R\@#.EK/E)0&6EOV-MI63DN0!
M@S8!)8F`L^*2`#-)7P"S]/4`L_G_`+J6LT_)`!/9M`$3EE0`L___`,Z6,V8F
M`?Z6?8XVEI.?XP&#-H$ED],C`+/O?P`SR?(!LW/V`+-Y_P"ZEC-/N0`3V;,!
MDY53`#-__P#.EK/E)0'ZEOV-MI43G^0!@S8!)HF`,V^?`#/Y]0"SQ.\!L_GR
M`+J6L\+$`)-4N0$3%ED`L_+R`,Z618Z6EGV.-I:3E.,!@S:!)I/3(P"SY'0`
MLT*?`+-S]@"S^?\`NI:SS[(`D]*S`9.54P"S__\`SI:SY54`_8W^EK./M@"3
M$ND!@S8!)Q-9*0"SXB(!L\54`#/Y_P`S?_\`DUFY`;J6L8T3%ED`_8WZEC-F
M-@%]CJZ6LX7&`!.?XP$#-H$GD],C`#-O?P"SQN(!L_/U`/V,.I:SQO8!_8XF
MEI/9LP&3E%,`-I:SYC0!-I:#-@$HDQ_I`1-9*0"S[R\!NI:S1/\!,W?V`/:6
ML_+R`#/&M`!]CI,55P"37K<!EI:REC/FU0&3E>,!D],C`+*6L^5U`/V..I,S
M!L\!,X<%`;.%'P%]CQ3A_8VS=O,`\8\8Z1SQ%.4,[0,W@2@<8+F/`4>%XX,P
M@2L#-`$K@S2!*@,Y`2J#.8$I`SH!*1,!`2R"@._@?[,Y<0;\(OA9Q5K@EX<`
M`(.WAY`#NP<`8P$+"$KP3NQ2Z(-'!0"JB2Z**HD3!]`#I<MCAN<`@T<9``4)
M_?L["3E!`S0+`#G,)O16Y-J$DPK0`TJ&SH4BA>_@S_>S!R0!">6#QP<`8X!7
M`X!DH01U\*)T`GGB:4)JHFH":^)P(H5"="%A@H"SA&1!C80%"2,@F@!*E/&_
M`435MP)K`43YOP%)1;<">>)I0FH":\&_<7$B\2;M!O67A```@[3DA"P`G&`^
MY8%'*H3OX-^8#>'B1[UF$6?UCV.%YP`I9V.:YP")12*%[^`/]Q,U%0`1H`%%
M*F><8+F/`4>1YZIP"G3J9$UA@H#OX!^C,7%.[0;]EWD``(.Y:7^#MPD`/N6!
M1QG%(OF#1P4`*H2)[TIT*F>#MPD`N8\!1V.7!PSJ<.II*6&"@";U2O'OX/^<
MJH19R2:%[^!/[DG!@T8U`1,)-0&;AB;]@>:#1AD`_=(#1S4!&P<G_27/(H52
MZ>_@S^DJBDJ%[^!/Z3L*J@`)*E*%[^"/Z<J'(H>7%@``DX8&>U*&B44JB>_@
M/Y,L`$J%[^"O]OU78PCU`.)'O6819_6/8X#G!$J%[^`O\4J%[^#?@":%2FKO
MX$_F2?$FA>_@S_0BA>_@;^U*=*IT"GF1MP-'&0`;!R?]2?,#1RD`.=NMOTJ%
M[_"_\-&W(ODF]4KQ4NGOX)^201$BX!=T```#-(1Q!N279@``DX;FA[,'1`"(
M8Q=V```#-H9PEQ4``).%A7'OX)^*$I0(8`)DHF`7)P``$P='JH%'NH87%@``
M$P9F&I<5``"3A05Q00%OX._R77%6[/UWA6K]<N$7$X<*`:+@)OQ*^$[T4O"&
MY#Z7%I&NB;,%)P`3AXH`"I<%9!=Y```#.<EF*HH3!O3_%Q4``!,%Y6V#-PD`
M'..!1^_@[^.;!`4`8UZ0`!.'"@$*ES,$AT";A_3_/I0#1X3_*>.=[Y=W``"#
MMR=E3H;2A9*7B&/OX*_:A6>A!XJ7F&.#-PD`N8\!1[GGA6(6D:9@!F3B=$)Y
MHGD">N)J86&"@+Z$_7<%9^$700<^ES,$)P`FAI,%\`(BA>_@;^]%U9=W``"#
MMX=?IH8BAI*7B&/2A>_@[^=5M^_@C_Y9<:+PINS*Z-+@AO3.Y%KX7O2#QP4`
M%WD```,YZ5FJA).'-_R3MQ<`,X3U`"*%@S<)`#[D@4?OX._(*HI,`":%[_`_
MQWG)JHGOX,_'8W9%"Q)+EWL``(.[*U<."P/'!`"FAY,&T`-C#`<28P;7``/'
M%P"%!WW[A9^#N0L`$P4J`#Z5VIGOX`_%(["I`#'%`[<+`(/'!``3A10`6I<4
M8Q,&T`,C@/8`@>N]H(-'!0`%!:,`]P"MPS:'A0;CF,?^DP;0`Y,'%P`C`-<`
M`T<$`(4'!02CC^?^=?LB9X,W"0"YCP%'^>.F<`9TYF1&::9I!FI">Z)[96&"
M@(-'!`"%"04$HX_Y_O';@T<$`(4)!02CC_G^_?/1MS:'7;=6_&+P9NR7>P``
M@[M+2H.\"P"#MPP`K<OFAX%)F&?.AJ$'A2EE_XTFDYHV`)=W``"3AV=2F$,%
M[P5'5H68P^_@S[<JC#')$YLY`-:&6H;FA>_@K\LCL(L!FX<9`(X'/IPC,`P`
MXGH"?.)L3L+9O=:%9H7OX(_9(["K`"J,$<T3FSD`V;^!1^&]P4J!246W5OQB
M\&;L[^!OX^)Z`GSB;`6WEW<``(.W)T*75@``DX:F6!=V```#-J9!DI>(8Y<5
M``"3A65";^!OVUUQ)OSY<HEDAN2BX$KX3O12\!.'A`$6D0J7EWD``(.YB3N#
MMPD`'..!1^_@C[_]=\$7DX8$`KZ6,X0F``5F*H>7%P``DX<G0I<6``"3AB9"
M!0:)12*%[^#/U/EUH163AP0"KI>SA"<`(H4%9J:%[^!/M1L$!0`!26-!!`(;
M"A0`4H7OX`^G*HD)R2*&TH:FA4J4[^`/UB,`!`")9^$'BI>88X.W"0"YCP%'
M@>^)8A:1IF!*A09DXG1">:)Y`GIA88*`[^`/U"V_A6;]=U%Q_7*3AT?W$X<&
M":+QINW*Z6+QAO7.Y=+A5OU:^5[U9NUJZ3Z7%I$NA+,%)P`3AX8("I<7?```
M`SPL+2J)@S<,`!SC@4<7%0``$P4%-^_P?YNJA),%\`)*A>_@S[@AQ1<5```3
M!64VRH7O\)_.2H6%9Y.'APB*EYAC@S<,`+F/`4=CE@<4A6(6D:YP#G3N9$YI
MKFD.:NIZ2GNJ>PI\ZFQ*;6UA@H`BA>_@[[:7%0``DX6E,N_@+Y$JA%W1A6?]
M>>$9$X<'"4Z7LPDG`!.'!PF3AP<)BI>%:GUZLXQ708-'!``3"HKW4I>7&P``
MDXMK+Q<;```3"VLO,PHG`,G+D<2BA2:%[^`OIC7%(H7OX*^0DP?U_Z*7*HV3
M!O`"8VCT`#&H(X`'`/T78P;T``/'!P#C"=?^(H7OX`^.*HU*A>_@CXUJE04%
MXWU5\8E%2HC>AR*'VH8%9DZ%[^#OM]*%3H7OX&^;`>F#IXSXO68A9_6/8X_G
M`I<5``"3A24F`47OX(^$*H3C#@7L@T<$`*W[D<2#QP0`FX<G_9G'!4T7%```
M$P0D(6&_@\<4`.G7_;>%14Z%[^!/BEW]SH47%0``$P7%(._P'[E.A>_@[Z15
MM>_@C[9!$9,%\`(BX`;D*H3OX(^F&<$3!!4`(H4"9*)@00%OX&^B>7&%9_UR
M2N@&]"+P)NP3AX<`%I$7>0```SGI#PJ7@S<)`!SC@4=-P8-'!0"JA,G/[]`_
M_Q,&%0"%9RJ$8^_'"GUW81?!![J7,X<G`*:%.H7OX"^0DP?T_ZJ7DP;P`F-H
M]0`1J".`!P#]%V.&IP`#QP<`XPG7_GUUA6=A%<$'JI<SA"<`DP7P`B*%[^"/
MG`W-8V*D!GUUA6=A%<$'JI<SA2<`[^`/F(5GH0>*EYAC@S<)`+F/`4>AYX5B
M%I&B<`)TXF1":45A@H"%9Z$'BI>88X,W"0"YCP%'G>.%8A:1HG`"=.)D0FD7
M%0``$P5%#45A;^`ODR,`!0!QOP%%;;?OX$^D.7$B^";T2O!.[`;\EW0``(.T
M1`"<8#[D@4=``!<9```3"<D-EWD``(.YR?^BA4J%[_#O[17!$D>#MPD`#@>Z
MEYAGF.-EUYAKH0>8XVW_HH5*A>_PS^ME\1<9```3"0D+EWD``(.Y"?RBA4J%
M[_`OZA7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_P#^AE\1<9```3
M"<D'EWD``(.Y2?BBA4J%[_!OYA7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_
MHH5*A>_P3^1E\1<9```3"0D%EWD``(.YB?2BA4J%[_"OXA7!$D>#MPD`#@>Z
MEYAGF.-EUYAKH0>8XVW_HH5*A>_PC^!E\1<9```3"<D!EWD``(.YR?"BA4J%
M[_#OWA7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_PS]QE\1<9```3
M"0G_EWD``(.Y">VBA4J%[_`OVQ7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_
MHH5*A>_P#]EE\1<9```3"<GSEWD``(.Y2>FBA4J%[_!OUQ7!$D>#MPD`#@>Z
MEYAGF.-EUYAKH0>8XVW_HH5*A>_P3]5E\1<9```3"8GXEWD``(.YB>6BA4J%
M[_"OTQ7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_PC]%E\1<9```3
M"<GUEWD``(.YR>&BA4J%[_#OSQ7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_
MHH5*A>_PS\UE\1<9```3"0GSEWD``(.Y"=ZBA4J%[_`OS!7!$D>#MPD`#@>Z
MEYAGF.-EUYAKH0>8XVW_HH5*A>_P#\IE\1<9```3"<GEEWD``(.Y2=JBA4J%
M[_!OR!7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_P3\9E\:*%%Q4`
M`!,%9>SO\$_%JH49Q1<5```3!67I[_`O^:*%%Q4``!,%!>SO\&_#JH49Q1<5
M```3!87L[_!/]Z*%%Q4``!,%I>SO\(_!JH4%S1<5```3!27<[_!O]2)GG&"Y
MCP%'J>-"=.)PHG0">>)IEQ4``).%)>P7%0``$P4EX"%A;_#/\J*%%Q4``!,%
M)>GO\`^]JH5YT1<5```3!27@[_#O\&6_[]#?[@$1(N@&[!=T```#-"3+3``7
M%0``$P4%WAQ@/N2!1^_PC[D5P8-'!0`!18G'DX<'_3,U\``B9QQ@N8\!1YGG
MXF!"9`5A@H`!1?6W[]#_Z1UQ!NPJCA=U```#-47*"&$3`X$"+O0R^#;\ON2Z
MX,+HQNR7=P``@[>'Q)J&<H:)19AC.N0!1QK@[]`_O1,%\`_OT+^X67&B\,%R
M063.Y-+@9NR&]*;LRNA6_%KX7O1B\!,'A``6D0J7EWP``(.\+,"#MPP`'..!
M1PE&@44JBN_0W\F3"?7_$]?Y0T&3LX?I`,(7P9.9C[.)^4!CQPD*P73!%),'
M!`'!:Z:7_5JSA"<`H0L=3!=Y```3">G!07L!1LZ%4H7OT'_%8PA5"5Z&IH52
MA>_0G]$!)6,*50=C<ZP&814SA*0`8W:4`*&H?11C:I0$(4;*A2*%[]`_OV7Y
MP7=!9\$700<^E[,')P`S!?1`3I7!9Z$'BI>88X.W#`"YCP%'J>/!8A:1IG`&
M=.9D1FFF:09JXGI">Z)[`GSB;&5A@H#:F>.=:?=]5>&W%Q4``!,%9=#O\-_J
M%Q4``!,%I<[O\!_J[]!_TT$1!N3OT/^?`27OT)_+$<$(8:)@00&"@#EQ)O1*
M\`;\%WD```,Y*:ZJA$P`%Q4``!,%Y<R#-PD`/N2!1^_P3YP=Q2+X@T<%`"J$
MC<.FA>_07Z<=S2)G@S<)`+F/`4?9XT)TXG"B=`)Y(6&"@$)T(F>#-PD`N8\!
M1Z:%%Q4``!,%!<BEY^)PHG0">2%A;_`OS":%3NSOT/^7JHDBA>_0?Y>JF8D)
M3H7OT-^7(HB7%P``DX=GLB:'EQ8``).&QK).AHE%*H3OT/_`(F>#-PD`N8\!
M1Y'KHH7B:4)T%Q4``!,%!<)-MT[L[]#?Q"+X3NSOT%_$EW<``).'AZ=)<8.X
M!P$#N(<!D'.4=YA[G'^F[LKJSN:&]J+REWD``(.YR9X#LPD`&N8!0Q<3```3
M`\.^9`@^X9<7``"3AX>^*HF:X#[T%Q,``!,#HZ:7%P``DX>GO::%%Q4``!,%
M!:::Y(+HQNS"\++TMOBZ_#[X`OSO\$^)$<6#1P4`*H1CE`<VTN)6_EKZ7O9B
M\N_0WX<!)>_0?[-C"@48@SH%`&.&"AA6A>_07X<3%!4`!00BA>_0GX<#QPH`
MJHLBC"J*#<\7&P``$PN+M]J&(H:)15Z%[]"?L(4*XH9C<XP`HH:SAX9`B0=C
M\]<`MH<#QPH`>105C#Z4B0MI^Y,*@047%0``$P5%JBF@`[6*`*$*#<&FA>_@
M?_\JA&79@T<%`.W7[_!/B771(H7OT#^?*H05X9,*`00#M`H`"<R#1P0`8X4'
M#B*%[_`/AV'I`[2*`*$*;?0BA>_0;_RJBE*%[]#O^[N*J@";BDI`5H7OT`_\
MEQ<``).'1Y?2B!<8```3"*BL(H>7%@``DX:&K%:&B44JB^_0OZ23!0`<6H7O
MT!^6_5=C&/4`[]!O^AQ!14=CGN<@9NZ3#($(YH5:A>_0'YHJA!GEZD>]9A%G
M]8]CAN<*EW<``(.WQX>#-@D`B&-:AQ<6```3!L:KB47OT#^=\FP!2C)G@[<)
M`+F/`4=CF`<NMG`6=/)Z4GNR>Q)\]F16:;9I4H46:G5A@H`BA>_0'Y`JA*$*
MXPD%\#6W`40EMR)U(!`9R::%[^!?[0'%@T<%`)7C"&0A!'WU-47OT"_NJHLJ
MBC5,-427&@``DXKJFQ,',`6-M>_0GXNJBF'=[]`/ZQ,4%0`%!#6]"EKOT"_I
MFP<%`.,7^O3J1Q,'`!R3]_<?XY#G]%:%[]!OZ::%*HH7%0``$P5EI>_@7^:J
MA6,!!18#-0D`[_#OQ"J,8PH%%&*%[]#/Y9L+!0"-1V/8=P,3A<O_EQ4``).%
MI:)BE>_0#_D)[9%'8XC[')N'N__BEP/'!P"3!_`"8P_W&J:%%Q4``!,%A83O
MX'_@8P8%$(-'!0!C@@<0$P<``V..YPZ7%0``DX4%C!<5```3!06"[_#/DN_0
MS_(JB)<8``"3B.BKEP<``).'9WI:AY<6``"3AD:>5H:)15*%[]!_B/U414F7
M'```DXQLJ1<,```3#.QWEQL``).+ZYPEH._03]T<06.7)P/OT*_M!20JB&;@
MHHCBAUJ'WH96AHE%4H7OT#^$DP4`'%*%[]"/]>,(E?Q:A>_0[_+2A1<%```3
M!85P[_#/B5*%[_`?MO)L+;479P```S<G:(,V"0`(8Q<6```3!D:(6H>)1>_0
MC_TAM>_PG[,R9X.W"0"YCP%'8YT'#B*%%G2V</9D5FFV:75A;]`O\0,\"0!U
MM8%%8H7OT%^#JH3C#P7N[_!?G"J)XTH%[I,%9?\!1B:%[]"/Z),+`0(91MZ%
M)H7OT*_TF4=C'/4(`E>W1T%#DX<',.,3]^P#UTL`D6>3AX=4XQSWZ@%&DP7I
M_":%[]#/Y!,&@`+FA2:%[]`/\9,'@`)C'O4$EQ@``).(R)9FB)<'``"3AR=E
M6H>7%@``DX8&B%:&B452A2,(`0KOT._R[;T#.8D`XP$)Y$J%[]#OQ8U'X_NG
MXG$5EQ4``).%I8-*E>_0C]GC$07B2HPQO1<5```3!<6"[_"_BV;N[]#O]-+B
M5OY:^E[V8O)F[N_0[_,Y<2+X%V0```,TY%)*\$[L!OPF]%+HLP=$`(1CDPE!
M`!=I```#.:E.@\<$"\Z%%P4``!,%15\#-PD`.N0!1Z.(]`KOX'^\&<4#1P4`
MDP<0`V,+]Q+O\&_*LP=$`(1C)H6-1@5&EP4``).%Y7[OT._!JH0=P1QI,P=$
M``ACC&,7!@``$P;&?>_03\&<:(QCW$43EY<"8T8'$+,'1`"(8XU&!4:7!0``
MDX4%?._0#[ZJA!=J```3"BI1#<'.A1<%```3!>50[^!?M"J&><&<:#,'1``(
M8XQC[]!/O+,'1`"$8P5&EP4``).%A7@FA>_0[Z^JA1<&```3!@9Y)H7OT.^Y
M$I0<8,Z%%P4``!,%14NCB`<*[^!_KR,XJ@`JA#G%DP4`'"*%[]!OS1L'%0"%
M1V/PYP+%1V,-]0"#-XH`JH8BAHQC%P4``!,%!7?OT`_2(F>#-PD`N8\!1['K
MXG!"=*)T`GGB:4)J(6&"@`,UB@#O\-^8(SBJ`"J$7?$7!0``$P4%<>_0C\Z#
M1Q4`XXH'[-FU`S>*`)QH#&.(8^_@?\TUO[,'1`"(8^_03\G]M>_0[]AY<2+P
M)NP&]!=D```#-"0UJH1,`!<%```3!>5''&`^Y(%'[^!_HP'-@T<%`(G+$P<`
M`V.&YP"!Q(/'!`"9ZR)G'&"YCP%'H>^B<`)TXF1%88*`)H5*Z._P+Y^3!?`"
M*HGOT*_#&<$3"14`2H7OT.^_$4:7!0``DX4%4N_0#YL9P4)I=;\B9QQ@N8\!
M1Y'K`G1"::)P)H7B9$5A;^!?K$KH[]"OSD$1$P4`"`;D[]#OG+=V74PW=^EA
MMR5%9Y.%%3"&!C=6,A`&!PSADX;FSY=%``"#M<5!$P9F1Q,'!Q\,Y13I$.T8
M\2,T!0(C.`4"(RP%!J)@00&"@#EQ(O@F]$KP5N0&_$[L4N@8=9,7-@`4>;J7
M@A>!DS.WYP"JA+J6*%T35]8!-I><])CX,HDNA).*A`,Q[9,'\`-CW"<)&PD)
M_!M::0";"1H`F@FBF:*%$P8`!%:%[]!OI!,$!`0FA>_0#^GC%33_&QIJ`#L)
M24%*ALZ%5H7OT&^B(ZPD!^)P0G2B=`)YXFE":J)J(6&"@),)``2[AZE`OHEC
M2O8"&XH)`).*A`-2AJ*%5I7OT`^?O%P3!P`$NX;Y`+3<XY'F_":%.PDY05*4
M[]"/XJVWLHGYMZ*)<;]Y<2+P)NQ2X`;T2NA.Y(.YA0(3BH4#DP8`^!/6.0`3
M=O8#,P?*``.Y!0.3!Q8`(P#7`!,'@`,NA*J$!29C5_<2$P<`!!&?D48S!?H`
M8W77%(E'8WGW$F,4!Q(BA>_0[]L3!H`#@452A>_0[ZJ35@D!$U>)`)/V]@^B
M!IM7B0$3=_</0@?5CQ-Y^0]B"=F/&]:)`9/6"0$"%K/G)P$3UXD`D_;V#Z(6
MT8\3=_</0A?5C^(9V8^SYS<!//@BA>_0[]4<8"*%X8,C@/0`'&#!@Z.`]``<
M8*&#(X'T`!Q@HX'T`!QDX8,C@O0`'&3!@Z."]``<9*&#(X/T`!QDHX/T`!QH
MX8,CA/0`'&C!@Z.$]``<:*&#(X7T`!QHHX7T`!QLX8,CAO0`'&S!@Z.&]``<
M;*&#(X?T`!QLHX?T`!QPX8,CB/0`''#!@Z.(]``<<*&#(XGT`!QPHXGT``)T
MHG#B9$)IHFD":D5A;]`/CQ,'@`,[!L=`@44S!?H`[]#OF<6](P`%`.&](P`%
M`*,`!0!Y%PD%XP4'[.VW(P`%`*,`!0`C`04`HP$%`'$7B4<1!>-E]^K1OY=F
M``"#MD8#;\#?^@$``@``````)7,O)7,```!$>6YA3&]A9&5R.CIB;V]T7T1Y
M;F%,;V%D97(``````$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C+W-E
M;&8O97AE``!E>&4``````"]P<F]C+R5I+R5S```````N`````````%!!4E]4
M14U0``````````!005)?4%)/1TY!344`````.@`````````O`````````"5S
M)7,E<P``4$523#5,24(``````````%!%4DQ,24(`4$523#5/4%0`````````
M`%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$``````!005)?
M0TQ%04X`````````4$%27T1%0E5'`````````%!!4E]#04-(10````````!0
M05)?1TQ/0D%,7T1%0E5'``````````!005)?1TQ/0D%,7U1-4$1)4@``````
M``!005)?5$U01$E2````````4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?
M0TQ%04X``````````#$`````````;'-E96L@9F%I;&5D`````')E860@9F%I
M;&5D``````!,1%],24)205)97U!!5$@`4UE35$5-```O=&UP`````%5315(`
M````55-%4DY!344``````````"4P,G@`````<&%R+0`````E<R5S)7,E<P``
M````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C
M=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y
M('EO=7(@;W!E<F%T:6]N*0H```````!0051(`````'!A<FP`````+G!A<@``
M``!S:&]R="!R96%D````````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U
M)7,````E<R5S=&5M<"TE=2TE=25S```````````8`````````'!E<FP`````
M,`````````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`V,0```%5N86)L
M92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*```````````M90```````"TM````````979A;"`G97AE8R`O
M=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U
M;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H
M)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I
M>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%
M7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S
M:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@
M9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ
M92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY
M("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@
M("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ
M90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D
M("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD[
M"FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I
M('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]
M"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F
M:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]
M*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F
M:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H
M<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*
M<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G
M35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%4
M12`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI
M.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\
M/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@
M)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R
M96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL
M96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64[
M"FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES
M=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S
M('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.
M('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA
M;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<
M)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO
M=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*
M;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)
M0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO
M<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@
M<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A
M(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM
M>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G
M:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG
M("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'
M24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I
M8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?
M<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@
M;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D
M8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M87)K97(@9F]U
M;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U
M9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S
M971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE
M.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E
M="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L(#`[
M"B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I
M<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@
M97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U
M=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R
M8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@
M.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_
M.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?
M1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT
M*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I
M;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE
M.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^
M("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E
M<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0[
M"GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@
M0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN
M9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN
M9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U
M;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#
M3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]
M($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T
M96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN
M9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L
M<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M
M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*
M;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B
M0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U
M;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q
M=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME
M>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M
M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@
M/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*
M9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI
M>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65]
M.PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II
M<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE
M(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M
M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A
M<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D[
M"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A21553
M12!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@
M;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*
M;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L
M;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I
M9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G
M*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@
M0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A
M9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!
M24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@
M>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2![
M"F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T
M($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@
M)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]
M"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF
M("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG
M*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E
M;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD
M8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@
M/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII
M;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?
M*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?
M:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D
M<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG
M="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ
M1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@
M(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M
M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A
M(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE
M=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D
M("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q
M6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E
M860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F
M:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*
M?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*
M)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H
M*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A
M;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*
M<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S=&%R
M=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R
M=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD968[
M"B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P
M;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@
M*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE
M<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U
M;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C
M:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP
M?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY
M("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA
M<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF
M:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S
M(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H
M;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F
M:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M
M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD
M?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF
M("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D
M<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L
M("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT
M('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE
M?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L
M:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S
M(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM
M>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL
M92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@
M)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I
M;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^
M+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@
M+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M
M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*
M<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R
M*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT
M*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E
M9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N
M86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD
M;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A
M<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII
M9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ
M4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F
M:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I
M9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@
M)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C
M:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H
M+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG
M+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@
M,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T
M87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN
M9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ
M6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL
M96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=
M.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*
M;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M
M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP
M=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O
M9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T
M('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E
M<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB
M97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M
M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[
M87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]
M("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6
M>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE
M("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U
M=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D
M>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;
M17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=
M*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R
M86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U
M-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE
M<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U
M;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@
M72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@
M6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@
M0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ
M0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E
M($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S
M*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E
M<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D
M97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@
M=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E
M($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D
M<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!
M4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*
M;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@
M/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G
M:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B
M*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(
M12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I
M8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I
M"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H
M95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C
M86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I
M('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@
M,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER
M.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*
M;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA
M;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I
M('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P
M96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O
M;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF
M(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@
M;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS
M=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.
M04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O
M9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?
M5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X]
M(#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P
M<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?
M4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^
M/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T
M=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB
M*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E
M86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6
M>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D
M9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI
M;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G
M;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI
M;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[
M7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P
M(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E
M>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]
M("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN
M960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@
M)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC
M:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D
M96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.
M5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@
M>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.
M140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE
M=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%
M04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"
M04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF
M("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]
M"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2![
M"G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*
M?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L
M(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA
M<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV
M96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*
M<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI0
M05(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O
M<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@
M9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M
M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`[
M"GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ
M.PI?7T5.1%]?"@!435!$25(``%1%35!$25(`5$5-4`````!435```````(FK
MS>\`````<&5R;'AS:2YC``````````!#04-(10```1L#.^P````<````H)#_
M_X`&```LDO__!`$``.22__\8`0``3J7__U`!``#ZI?__O`$``%2F___H`0``
M7*?__T`"``"VI___9`(``)RH__^D`@``5JK__Q`#``!^JO__)`,``$2K__]@
M`P``1JO__W0#```<K?__R`,``#ZM___H`P``0*[__RP$``"8L?__8`0``.:Q
M__^$!```*K+__YP$``!.L___[`0``&:S__\(!0``0+3__V`%``!&N?__``8`
M`/:Z__\X!@``FKO__[0&``#NN___U`8``,J\__\,!P``?+[__T@'````````
M$``````````#>E(``7P!`1L-`@`0````&````""1__\B``````<!`#0````L
M````Q)'__VH2````1`[`!5B(!($"B0:2"),*E`P#,!(*P43(1,E$TD331-1$
M#@!""P``:````&0```#VH___K`````!"#D!$@0*(!$R6$%*2"),*E`QFB0:5
M#F;)0M)"TT+40M5"UD+!1,A"#@!"#D"!`H@$B0:2"),*E`R5#I804,G2T]35
MUD26$$+61)((DPJ4#)801M)"TT+40M8`*````-`````VI/__6@````!"#K`!
M1H@$B0:!`@)&"L%"R$+)0@X`0@L```!4````_````&2D__\(`0```$(.P`%$
MDPJ!`EB(!$;(4,%"TT(.`$(.P`&!`H@$DPI$B0:2"'*4#`)8U%0*R$+)0M)"
M"U*4#$C(R=+42(@$B0:2")0,````(````%0!```4I?__6@````!"#A!"B`1*
M@0)HR$+!7@X`````/````'@!``!*I?__Y@````!"#E!$E0Y:#M`@B`2)!I((
MDPJ4#($"`GH*#E!"P4+(0LE"TD+30M1"U4(.`$(+`&@```"X`0``\*7__[H!
M````0@YP5(@$B0:2")0,@0*3"I80EQ("T`K!0LA"R4+20M-"U$+60M="#@!"
M"W"5#I@4F18"6`K50MA"V40+5M78V425#I@4F19&U=C91I4.F!29%D;50MA"
MV0```!`````D`@``/J?__R@`````````.````#@"``!2I___Q@````!"#E!$
MB092#M!`@0*(!)((DPJ4#`*8"@Y00L%$R$+)0M)"TT+40@X`0@L`$````'0"
M``#<I___`@````````!0````B`(``,JG___6`0```$8.\`%F#O`AB`2)!I((
MF!2!`I,*E`R5#I80EQ*9%IH8`F(*#O`!0L%"R$+)0M)"TT+40M5"UD+70MA"
MV4+:0@X`0@L<````W`(``$RI__\B`````$(.$$B(!($"4,A"P4(.`$````#\
M`@``3JG__P(!````0@XP4@ZP()((@0*(!(D&`J@*#C!"P4+(0LE"TD(.`$(+
M5@H.,$+!0LA"R4+22@X`1`L`,````$`#```,JO__6`,```!"#D!*B`2)!I((
MDPJ!`@,*`PK(0L%"R4+20M-2#@!$"P```"````!T`P``,*W__TX`````0@X@
M1(@$@0)Z"L%"R$(.`$(+`!0```"8`P``6JW__T0`````0@Y@0H$2`$P```"P
M`P``AJW__R0!````0@YP1(@$7`[P@`23"I0,F1:!`HD&D@B5#I80EQ*8%`+"
M"@YP0L%"R$+)0M)"TT+40M5"UD+70MA"V4(.`$(+&``````$``!:KO__&```
M``!"#A!"@0)0P4(.`%0````<!```5J[__]H`````0@Y`1HD&D@B!`FB(!%H*
MR$+!0LE"TD(.`$(+0LA8P4+)0M)"#@!$#D"!`H@$B0:2"$0*DPH"1--"R$H+
M0I,*1,C31(@$DPJ<````=`0``-BN__\&!0```$H.\`):B0:2"),*@0*(!`)P
ME`R5#I80EQ*8%`,D`9D6`CS94@K!0LA"U4+60M="V$+)0M)"TT340@X`0@L"
M7ID6`U`!V6+4U=;7V%;(0L%"R4+20M-"#@!$#O`"@0*(!(D&D@B3"I0,E0Z6
M$)<2F!29%@/>`-E"F19$U-76U]C93)0,E0Z6$)<2F!29%@``-````!0%```^
ML___L`$```!"#D!"B`12D@B3"H$"B0:4#`-&`0K!0LA"R4+20M-"U$(.`$(+
M``!$````3`4``+:T__^D`````$(.,$:(!(D&@0("0@K!0LA"R4(.`$(+1)((
M;`K20@M,R$+20L%$R4(.`$0.,($"B`2)!D*2"``P````E`4``!B*__^*`0``
M`$(.8$R!`HD&B`22"),*`PX!"L%"R$+)0M-$TD(.`$(+````'````,@%``#>
MM/__5`````!"#A!&@0("2,%"#@`````T````Z`4``!*U___<`````$(.0$Z(
M!(D&D@B5#H$"DPJ4#`)V"L%"R$+)0M)"TT+40M5"#@!""S@````@!@``MK7_
M_[(!````0@XP3(@$B0:4#($"D@B3"@-,`0K(0L%"R4+20M-"U$(.`$0+````
M`````!````!<!@``++?__PP`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````0``````````
M`P````````$`````````"P,````````!`````````!4#````````'0``````
M``"_!````````"``````````<*L````````A``````````@`````````&0``
M``````!XJP```````!L`````````"``````````:`````````("K````````
M'``````````(``````````0`````````V`(```````#U_O]O```````&````
M````!0````````"`$`````````8`````````\`8````````*`````````/4$
M````````"P`````````8`````````!4````````````````````#````````
M`+BM`````````@````````!P!0```````!0`````````!P`````````7````
M`````+@8````````!P````````"H%@````````@`````````@`<````````)
M`````````!@`````````'@`````````(`````````/O__V\``````0``"```
M``#^__]O`````$@6````````____;P`````"`````````/#__V\`````=A4`
M``````#Y__]O``````L`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#__________P``````````,!X````````P'@```````#`>
M````````,!X````````P'@```````#`>````````,!X````````P'@``````
M`#`>````````,!X````````P'@```````#`>````````,!X````````P'@``
M`````#`>````````,!X````````P'@```````#`>````````,!X````````P
M'@```````#`>````````,!X````````P'@```````#`>````````,!X`````
M```P'@```````#`>````````,!X````````P'@```````#`>````````,!X`
M```````P'@```````#`>````````,!X````````P'@```````#`>````````
M,!X````````P'@```````#`>````````,!X````````P'@```````#`>````
M````,!X````````P'@```````#`>````````,!X````````P'@```````#`>
M````````,!X````````P'@```````#`>````````,!X````````P'@``````
M`#`>````````,!X````````P'@```````#`>````````,!X```````"(JP``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"E!!4BYP;0H`````````````````````````
M````````````````````````````````````````````````````````````
M1T-#.B`H4U5312!,:6YU>"D@,3,N,BXQ(#(P,C,Q,3,P(%MR979I<VEO;B`W
M-#$W-#-C,#(X9&,P,&8R-V(Y8SAB,60U,C$Q8S%F-C`R9C)F9&1D70!!4@``
M`')I<V-V``%(````!!`%<G8V-&DR<#%?;3)P,%]A,G`Q7V8R<#)?9#)P,E]C
M,G`P7WII8W-R,G`P7WII9F5N8V5I,G`P7WIM;75L,7`P```N<VAS=')T86(`
M+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU
M+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I
M;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YT97AT`"YR;V1A=&$`+F5H7V9R
M86UE7VAD<@`N96A?9G)A;64`+G!R96EN:71?87)R87D`+FEN:71?87)R87D`
M+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT
M`"YR:7-C=BYA='1R:6)U=&5S````````````````````````````````````
M```````````````````````````````````````````````````+`````0``
M``(`````````<`(```````!P`@```````"$````````````````````!````
M````````````````$P````<````"`````````)0"````````E`(````````D
M````````````````````!````````````````````"8````'`````@``````
M``"X`@```````+@"````````(`````````````````````0`````````````
M```````X````!0````(`````````V`(```````#8`@```````"0#````````
M!@`````````(``````````0`````````-````/;__V\"```````````&````
M``````8```````#L``````````8`````````"````````````````````#X`
M```+`````@````````#P!@```````/`&````````D`D````````'`````@``
M``@`````````&`````````!&`````P````(`````````@!````````"`$```
M`````/4$```````````````````!````````````````````3@```/___V\"
M`````````'85````````=A4```````#,``````````8``````````@``````
M```"`````````%L```#^__]O`@````````!(%@```````$@6````````8```
M```````'`````@````@```````````````````!J````!`````(`````````
MJ!8```````"H%@```````!`"````````!@`````````(`````````!@`````
M````=`````0```!"`````````+@8````````N!@```````!P!0````````8`
M```5````"``````````8`````````'D````!````!@`````````P'@``````
M`#`>````````P`,``````````````````!``````````$`````````!^````
M`0````8`````````\"$```````#P(0```````.@M```````````````````$
M````````````````````A`````$````"`````````-A/````````V$\`````
M``!W00``````````````````"````````````````````(P````!`````@``
M``````!0D0```````%"1````````[`````````````````````0`````````
M``````````":`````0````(`````````0)(```````!`D@```````'`&````
M```````````````(````````````````````I````!`````#`````````'"K
M````````<)L````````(`````````````````````0`````````(````````
M`+,````.`````P````````!XJP```````'B;````````"```````````````
M``````@`````````"`````````"_````#P````,`````````@*L```````"`
MFP````````@````````````````````(``````````@`````````RP````8`
M```#`````````(BK````````B)L````````P`@````````<`````````"```
M```````0`````````-0````!`````P````````"XK0```````+B=````````
M2`(```````````````````@`````````"`````````#9`````0````,`````
M`````+``````````H````````%`````````````````````(````````````
M````````WP````@````#`````````%"P````````4*`````````H````````
M````````````"````````````````````.0````!````,```````````````
M`````%"@````````5@````````````````````$``````````0````````#M
M`````P``<`````````````````````"FH````````%,`````````````````
M```!`````````````````````0````,`````````````````````````^:``
E``````#_`````````````````````0``````````````````````
